ColumnPool

Struct ColumnPool 

pub struct ColumnPool<ColumnType, FilterType> { /* private fields */ }
Holds all columns generated so far

Implementations

Source

impl<ColumnType, FilterType> ColumnPool<ColumnType, FilterType>

pub fn new() -> Self

Source

impl<ColumnType, FilterType> ColumnPool<ColumnType, FilterType>

pub fn count(&self) -> usize

Total number of columns in pool

pub fn get_column(&self, id: ColumnId) -> &Column<ColumnType>

Returns a specific column from the pool

pub fn get_all_columns(&self) -> (ColumnTicket, Iter<'_, Column<ColumnType>>)

Get Iterator of all columns in column pool and associated ticket

pub fn add_column( &mut self, column_data: ColumnType, column_ticket: ColumnTicket, ) -> bool
where ColumnType: PartialEq,

Adds a column to the column pool The column_ticket that was handed out during get_columns must be returned, to ensure column pool consistency in a multithreaded environment