UserModelMeta

Trait UserModelMeta 

pub trait UserModelMeta<Constr: Clone, Var: Clone, Env: LPEnv, Model: LPModel<Constr, Var, Env>> {
    // Required method
    fn get_pattern_vars(&mut self) -> &mut HashMap<ColumnId, Var>;

    // Provided method
    fn callback_before_optimize(
        &mut self,
        lower_bound: f64,
        best_known: &RwLock<(f64, Vec<(f64, ColumnId)>)>,
        model: &mut Model,
    ) { ... }
}
Trait to be implemented on ModelMeta data.

Required Methods

fn get_pattern_vars(&mut self) -> &mut HashMap<ColumnId, Var>

Return the column selection decision variables

Provided Methods

fn callback_before_optimize( &mut self, lower_bound: f64, best_known: &RwLock<(f64, Vec<(f64, ColumnId)>)>, model: &mut Model, )

Callback that is called just prior to optimizing the LP model Can be used to make custom modifications

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors